FromClientConfigAndContext

Trait FromClientConfigAndContext 

pub trait FromClientConfigAndContext<C: ClientContext>: Sized {
    // Required method
    fn from_config_and_context(_: &ClientConfig, _: C) -> KafkaResult<Self>;
}
Create a new client based on the provided configuration and context.

Required Methods

fn from_config_and_context(_: &ClientConfig, _: C) -> KafkaResult<Self>

Creates a client from a client configuration and a client context.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<C, R> FromClientConfigAndContext<C> for FutureProducer<C, R>
where C: ClientContext + 'static, R: AsyncRuntime,

Source

impl<C, R> FromClientConfigAndContext<C> for StreamConsumer<C, R>
where C: ConsumerContext + 'static, R: AsyncRuntime,

Creates a new StreamConsumer starting from a ClientConfig.

Source

impl<C: ClientContext> FromClientConfigAndContext<C> for AdminClient<C>

Source

impl<C: ConsumerContext> FromClientConfigAndContext<C> for BaseConsumer<C>

Creates a new BaseConsumer starting from a ClientConfig.

Source

impl<C> FromClientConfigAndContext<C> for BaseProducer<C>
where C: ProducerContext,

Source

impl<C> FromClientConfigAndContext<C> for ThreadedProducer<C>
where C: ProducerContext + 'static,